import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="liveblook",
    version="1.0.0",
    author="Thecrazedpotato",
    author_email="floppyfish118@gmail.com",
    description="find live blooks with threading",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)